Rdocumentation
powered by
Learn R Programming
ibmdbR (version 1.47.1)
ida.list methods: Available methods for ida.list
Description
ida.list
objects provide methods that will behave exactly like or very similar to methods defined on a regular
list
. The following methods are currently supported: length, names, print.
For details see the documentation of
ida.list
.
Arguments