Learn R Programming

ibmdbR (version 1.42.2)

idaListModels and idaModelExists: List all predictive models in the database

Description

Use these function to list all models in the schema of the current user that were created using the idaNaiveBayes or idaKMeans functions or check whether a model with a specific name exists.

Usage

idaListModels()
idaModelExists(modelname)

Arguments

modelname
The name of a predictive model.

Value

  • idaListModels returns a data frame that contains a list of the predictive models that are stored in the current schema and information about each one. idaModelExists returns a boolean value depending on whether the model exists or not.

Examples

Run this code
#Get a list of all models
q <- idaListModels();

Run the code above in your browser using DataLab