Learn R Programming

ibmdbR (version 1.36.7)

idadf,idaSave,idaUpdate: Query, store and update data in the database.

Description

These functions allows to query, store and update data in the database. Usually, it is easier to use idaQuery,ida.data.frame and as.ida.data.frame instead of these methods. They can be useful, however, if an explicit connection object is needed, e.g. if there are several connections to different databases.

Usage

idadf(idaConn, query)
idaSave(idaConn, dfrm, tblName = "", rowName = "", conType = "odbc")
idaUpdate(db2Conn, updf, dfrm, idaIndex = "", conType = "odbc")

Arguments

idaConn
The IDA connection object.
db2Conn
The IDA connection object.
query
A query.
dfrm
A data.frame to store.
tblName
Name of the table to which to store the data.
rowName
Name of the row name column.
updf
Name of the table to update.
idaIndex
Name of the index column.
conType
Type of the connection.

Details

idadf,idaSave and idaUpdate are simple wrappers around the RODBC functions sqlQuery, sqlSave and sqlUpdate. Usually, it is easier to use idaQuery,ida.data.frame and as.ida.data.frame instead of these methods.

See Also

idaQuery,ida.data.frame,as.ida.data.frame,sqlQuery,sqlSave,sqlUpdate

Examples

Run this code
# create connection to DB
con <- idaConnect("BLUDB", "", "")

# create data.frame from table
df <- idadf(con, "SELECT * FROM IRIS")

# close the connection again
idaClose(con)

Run the code above in your browser using DataLab