Learn R Programming

ibmdbR (version 1.42.2)

idaConnect, idaClose: Open or closes a IDA database connection

Description

These functions are used to open or close an existing IDA database connection.

Usage

idaConnect(dsn, uid = "", pwd = "", conType = "odbc")

idaClose(idaConn, conType = "odbc")

Arguments

dsn
The DSN of the data base.
uid
The user name.
pwd
The password.
conType
The connection type.
idaConn
The connection object.

Details

Opens or closes a connection to a database. Currently, RODBC is used as underlying library, this might change, however, in the future.

Examples

Run this code
#Connect locally 
con <- idaConnect('BLUDB','','')

#Close the connection
idaClose(con)

Run the code above in your browser using DataLab