ida.data.frame).idaMerge(x, y, by=intersect(x@cols, y@cols), by.x=by, by.y=by,
all=FALSE, all.x=all, all.y=all, sort=TRUE,
suffixes=c("_x", "_y"), table=NULL)ida.data.frame object to be merged.ida.data.frame object to be merged.x and y are to be appended to the result.
If set to FALSE, only columns common to both x and y are included in the output.
This parameter overrides the all.x<all.x=TRUE and all.yall.xx or y.
Noteida.data.frame object.by or both by.x and by.y are of length 0 (a
length zero vector or NULL), the result, r, is the
Cartesian product of x and y, that is, a cross join.
If non-merged columns of the data frames have identical names and are to be included in the output,
suffixes are appended to the names of the corresponding columns in the output to make their names.
Note that this function creates, in the current database, a view that corresponds to the output object.
Within the current session, this view can be accessed using the same IDA data frame object.
However, it is persistent and, after it is no longer needed, it must be dropped manually.ida.data.frameidf <- ida.data.frame('IRIS')
#Perform a self-join
idf2 <- idaMerge(idf,idf,by="ID")Run the code above in your browser using DataLab