Usage
idaMerge(x, y, by=intersect(x@cols, y@cols), by.x=by, by.y=by,
all=FALSE, all.x=all, all.y=all, sort=TRUE,
suffixes=c("_x", "_y"), table=NULL)Arguments
x
The first ida.data.frame object to be merged.
y
The second ida.data.frame object to be merged.
by
Specification of the common columns; see the
Details section.
by.x
Specification of the common columns; see the
Details section.
by.y
Specification of the common columns; see the
Details section.
all
Whether non-matching columns of x and y are to be appended to the result.
If set to FALSE, only columns common to both x and y are included in the output.
This parameter overrides the all.x<
all.x
If columns from only one of the IDA data frames being merged are to be included in the output,
set its corresponding parameter to TRUE and the other parameter to FALSE.
In SQL database terminology, specifying all.x=TRUE and all.y
sort
This parameter is ignored. The output is never sorted regardless of the setting of this parameter.
suffixes
Two 2-character strings, each of which specifies a suffix that is
used when generating column names.
By specifying different suffixes, you can ensure that each column
can be uniquely attributed to either x or y.
Note
table
Name of the output IDA data frame.