Learn R Programming

ibmdbR (version 1.42.2)

idaShowTables: Return a list of tables

Description

Returns a data frame that contains the names of the tables contained in the current database.

Usage

idaShowTables(showAll=FALSE)

Arguments

showAll
List all tables that are listed in the catalog of the current database (TRUE) or only those tables that are in the current schema (FALSE).

Value

  • A data frame with the columns Schema, Name, Owner, and Type.

Examples

Run this code
#Get a list of all tables in the current schema
tabs <- idaShowTables()

Run the code above in your browser using DataLab